@@ -26,7 +26,7 @@ class Compiler(_Compiler):
     #     else:
     #       self.buffer('{{%s(%s)}}'%(mixin.name,mixin.args))
 
-    def interpolate(self,text):
+    def interpolate(self, text, escape=True):
         return self._interpolate(text,lambda x:'{{%s(%s)}}' % (ESCAPE_FUNC, x))
 
     def visitMixin(self,mixin):
